Skip to main content Module csharp Copy item path Source CALL_QUERY Tree-sitter query for extracting C# method invocations. ELEMENT_QUERY Tree-sitter query for extracting C# elements (methods, constructors, classes,
interfaces, records, structs, and enums). IMPORT_QUERY Tree-sitter query for extracting C# using directives. REFERENCE_QUERY Tree-sitter query for extracting C# type references (base types, generic args). extract_inheritance Extract base class and interface names from a C# class, interface, or record node. find_method_for_receiver Return the method or constructor name when node is a method_declaration
or constructor_declaration that is nested inside a class, interface, or
record body.